# Дополнительные функции

* [Визуализация изменений параметров модели с регуляризацией](https://github.com/Ackrome/matplobblib/blob/master/matplobblib/ml/additional_funcs/b2_visual#readme)
* [Вычисление метрик качества](https://github.com/Ackrome/matplobblib/blob/master/matplobblib/ml/additional_funcs/metrics#readme)
* [Математические функции](https://github.com/Ackrome/matplobblib/blob/master/matplobblib/ml/additional_funcs/math_funcs#readme)
* [Разделение на части (фолды)](https://github.com/Ackrome/matplobblib/blob/master/matplobblib/ml/additional_funcs/folds#readme)
